@@ -34,7 +34,7 @@
 
 #define PANGO_LIGATURE_HACK_DEBUG
 
-#include <config.h>
+#include "config.h"
 
 #define PANGO_TYPE_X_FONT              (pango_x_font_get_type ())
 #define PANGO_X_FONT(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), PANGO_TYPE_X_FONT, PangoXFont))
@@ -1543,7 +1543,7 @@ pango_x_render_layout (Display         *display,
   int width;
   int y_offset = 0;
 
-  gboolean first = FALSE;
+  gboolean first = TRUE;
   
   g_return_if_fail (display != NULL);
   g_return_if_fail (layout != NULL);
